Learn R Programming

alr3 (version 1.0.3)

conf.intervals: Compute marginal confidence intervals for regression estimates

Description

Thus function computes confidence intervals coefficient estimates for a regression object.

Usage

conf.intervals(object,level=.95,f=qnorm((1-level)/2))

Arguments

object
A regression object
level
one minus significance level, default = .95
f
multiplier for the intervals. For conf.intervals.default, the default choice of f is qnorm((1-level)/2), using the normal distribution to get intervals, and t-intervals for conf.invtervals.lm.

Value

  • Returns a matrix, with one row for each estimated parameter, and three columns, the first giving the coefficient estimate, then the lower limit of the confidence interval, and then the upper limit.

Examples

Run this code
data(forbes)
m1 <- lm(Lpres ~ Temp, data = forbes)
conf.intervals(m1, level = .95) # .95 is the default.

Run the code above in your browser using DataLab