Learn R Programming

alr3 (version 1.1.11)

longley: Longley data

Description

Longley (1967) data to demonstrate inadequacies of regression computer programs then available.

Arguments

source

Longley, J. (1967). An appraisal of least squares programs for the electronic computer from the point of view of the user. J. Amer. Statist. Assoc., 62, 819-41.

References

Weisberg, S. (2005). Applied Linear Regression, 3rd edition. New York: Wiley, Problem 4.10.

Examples

Run this code
data(longley)

Run the code above in your browser using DataLab