Learn R Programming

alr3 (version 1.0.3)

wblake: West Bearskin Lake walleye data.

Description

Data on samples of Walleye collected in West Bearskin Lake, Minnesota, in 1991. The file wblake includes only fish of ages 8 or younger, while wblake2 adds a few older fish.

Arguments

source

Minnesta Department of Natural Resources

References

Weisberg, S. (2005). Applied Linear Regression, 3rd edition. New York: Wiley, Section 1.1.

Examples

Run this code
data(wblake)  # excludes fish age 9 or older
data(wblake2)  # all fish

Run the code above in your browser using DataLab