multiplier for the intervals. For conf.intervals.default, the
default choice of f is qnorm((1-level)/2), using the normal distribution
to get intervals, and t-intervals for conf.invtervals.lm.
Value
Returns a matrix, with one row for each estimated parameter, and three
columns, the first giving the coefficient estimate, then the
lower limit of the confidence interval,
and then the upper limit.