loess smooth for the graph, along with
a loess smooth from the plot of the fitted values on $u$.mmps(object,exclude=NULL,layout=NULL,ask,...)
mmp.lm(object, u = predict(object), mean = TRUE, sd = FALSE,
label = deparse(substitute(u)), degree = 1, span = 2/3,
colors = c("blue", "red"), ...)predict
method defined.c(2,4) would exclude the second and fourth
terms in the model, excluding the intercept.c(2,3) means two rows and three columns.predict(object). Can be any other
vector of length equal to the number of observations in the object.loess. The
usual default for loess is 2, but the default here is one.loess.loess and plotmmp draws one marginal model plot. mmps draws all marginal model plots,
versus each of the terms in the model and versus fitted values. mmps
should not be used if some of the terms in the model are factors or
interactions.loess, plotdata(ufcwc)
c1 <- lm(Height~Dbh,ufcwc)
mmp(c1,ufcwc$Dbh,label="Diameter, Dbh",color=c("black","black"))
mmps(c1)Run the code above in your browser using DataLab